@@ -1,8 +1,11 @@
 from .iam_pomes import (
-    IamServer, logger_register,
+    IamServer,
     login_callback, token_exchange,
     user_login, user_logout, user_token
 )
+from .iam_services import (
+     logger_register
+)
 from .jusbr_pomes import (
     jusbr_setup, jusbr_get_token
 )
@@ -18,9 +21,11 @@ from .token_pomes import (
 
 __all__ = [
     # iam_pomes
-    "IamServer", "logger_register",
+    "IamServer",
     "login_callback", "token_exchange",
     "user_login", "user_logout", "user_token",
+    # iam_services
+    "logger_register",
     # jusbr_pomes
     "jusbr_setup", "jusbr_get_token",
     # keycloak_pomes
