@@ -5,7 +5,7 @@ from enum import StrEnum
 from logging import Logger
 from pypomes_core import TZ_LOCAL, exc_format
 from pypomes_crypto import crypto_jwk_convert
-from threading import Lock
+from threading import RLock
 from typing import Any, Final
 
 
@@ -17,23 +17,18 @@ class IamServer(StrEnum):
     IAM_KEYCLOAK = "iam-keycloak"
 
 
-# the logger for IAM service operations
-# (used exclusively at the HTTP endpoint - all other functions receive the lgger as parameter)
-__IAM_LOGGER: Logger | None = None
-
 # registry structure:
 # { <IamServer>:
 #    {
+#       "base-url": <str>,
 #       "client-id": <str>,
 #       "client-secret": <str>,
 #       "client-timeout": <int>,
 #       "recipient-attr": <str>,
-#       "public_key": <str>,
+#       "public-key": <str>,
 #       "pk-lifetime": <int>,
 #       "pk-expiration": <int>,
-#       "base-url": <str>,
-#       "cache": <FIFOCache>,
-#       "redirect-uri": <str>  <-- transient
+#       "cache": <FIFOCache>
 #    },
 #    ...
 # }
@@ -45,8 +40,10 @@ __IAM_LOGGER: Logger | None = None
 #          "refresh-token": <str>
 #          "access-expiration": <timestamp>,
 #          "refresh-expiration": <timestamp>,
-#          "login-expiration": <timestamp>,    <-- transient
-#          "login-id": <str>,                  <-- transient
+#          # transient attributes:
+#          "login-expiration": <timestamp>,
+#          "login-id": <str>,
+#          "redirect-uri": <str>
 #       }
 #    },
 #   ...
@@ -55,29 +52,7 @@ _IAM_SERVERS: Final[dict[IamServer, dict[str, Any]]] = {}
 
 # the lock protecting the data in '_IAM_SERVER'
 # (because it is 'Final' and set at declaration time, it can be accessed through simple imports)
-_iam_lock: Final[Lock] = Lock()
-
-
-def _get_logger() -> Logger | None:
-    """
-    Retrieve the registered logger for *IAM* operations.
-
-    This function is invoked exclusively from the HTTP endpoints.
-    All other functions receive the logger as parameter.
-
-    :return: the registered logger for *IAM* operations.
-    """
-    return __IAM_LOGGER
-
-
-def _register_logger(logger: Logger) -> None:
-    """
-    Register the logger for *IAM* operations
-
-    :param logger: the logger to be rergistered
-    """
-    global __IAM_LOGGER
-    __IAM_LOGGER = logger
+_iam_lock: Final[RLock] = RLock()
 
 
 def _get_public_key(iam_server: IamServer,
@@ -105,7 +80,7 @@ def _get_public_key(iam_server: IamServer,
             # obtain a new public key
             url: str = f"{registry["base-url"]}/protocol/openid-connect/certs"
             if logger:
-                logger.debug(msg=f"GET '{url}'")
+                logger.debug(msg=f"GET {url}")
             try:
                 response: requests.Response = requests.get(url=url)
                 if response.status_code == 200:
@@ -121,7 +96,7 @@ def _get_public_key(iam_server: IamServer,
                 elif logger:
                     msg: str = f"GET failure, status {response.status_code}, reason '{response.reason}'"
                     if hasattr(response, "content") and response.content:
-                        msg += f", content '{response.content}'"
+                        msg += f", content {response.content}"
                     logger.error(msg=msg)
                     if isinstance(errors, list):
                         errors.append(msg)
@@ -185,7 +160,7 @@ def _get_user_data(iam_server: IamServer,
     users: dict[str, dict[str, Any]] = _get_iam_users(iam_server=iam_server,
                                                       errors=errors,
                                                       logger=logger)
-    if users:
+    if isinstance(users, dict):
         result = users.get(user_id)
         if not result:
             result = {
