@@ -10,27 +10,26 @@ from typing import Any
 
 from .iam_common import (
     IamServer, _iam_lock,
-    _register_logger, _get_iam_users, _get_iam_registry,
-    _get_login_timeout, _get_user_data, _get_public_key
+    _get_iam_users, _get_iam_registry,
+    _get_login_timeout, _get_user_data,  # _get_public_key
 )
 from .token_pomes import token_validate
 
 
-def logger_register(logger: Logger) -> None:
-    """
-    Register the logger for IAM operations.
-
-    :param logger: the logger to be registered
-    """
-    _register_logger(logger=logger)
-
-
 def user_login(iam_server: IamServer,
                args: dict[str, Any],
                errors: list[str] = None,
-               logger: Logger = None) -> dict[str, str]:
+               logger: Logger = None) -> str:
     """
-    Build the callback URL for redirecting the request to *iam_server*'s authentication page.
+    Build the URL for redirecting the request to *iam_server*'s authentication page.
+
+    These are the expected attributes in *args*:
+        - user-id: optional, identifies the reference user (aliases: 'user_id', 'login')
+        - redirect-uri: a parameter to be added to the query part of the returned URL
+
+    If provided, the user identification will be validated against the authorization data
+    returned by *iam_server* upon login. On success, the appropriate URL for invoking
+    the IAM server's authentication page is returned.
 
     :param iam_server: the reference registered *IAM* server
     :param args: the arguments passed when requesting the service
@@ -39,7 +38,7 @@ def user_login(iam_server: IamServer,
     :return: the callback URL, with the appropriate parameters, of *None* if error
     """
     # initialize the return variable
-    result: dict[str, str] | None = None
+    result: str | None = None
 
     # obtain the optional user's identification
     user_id: str = args.get("user-id") or args.get("user_id") or args.get("login")
@@ -63,18 +62,18 @@ def user_login(iam_server: IamServer,
                 user_data["login-expiration"] = int(datetime.now(tz=TZ_LOCAL).timestamp()) + timeout \
                     if timeout else None
                 redirect_uri: str = args.get("redirect-uri")
+                user_data["redirect-uri"] = redirect_uri
 
                 # build the login url
                 registry: dict[str, Any] = _get_iam_registry(iam_server=iam_server,
                                                              errors=errors,
                                                              logger=logger)
                 if registry:
-                    registry["redirect-uri"] = redirect_uri
-                    result = {"login-url": (f"{registry["base-url"]}/protocol/openid-connect/auth"
-                                            f"?response_type=code&scope=openid"
-                                            f"&client_id={registry["client-id"]}"
-                                            f"&redirect_uri={redirect_uri}"
-                                            f"&state={oauth_state}")}
+                    result = (f"{registry["base-url"]}/protocol/openid-connect/auth"
+                              f"?response_type=code&scope=openid"
+                              f"&client_id={registry["client-id"]}"
+                              f"&redirect_uri={redirect_uri}"
+                              f"&state={oauth_state}")
     return result
 
 
@@ -86,7 +85,8 @@ def user_logout(iam_server: IamServer,
     Logout the user, by removing all data associating it from *iam_server*'s registry.
 
     The user is identified by the attribute *user-id*, *user_id*, or "login", provided in *args*.
-    If unsuccessful, this operation fails silently, unless an error has ocurred.
+    If successful, remove all data relating to the user from the *IAM* server's registry.
+    Otherwise, this operation fails silently, unless an error has ocurred.
 
     :param iam_server: the reference registered *IAM* server
     :param args: the arguments passed when requesting the service
@@ -201,9 +201,9 @@ def login_callback(iam_server: IamServer,
     """
     Entry point for the callback from *iam_server* via the front-end application, on authentication operations.
 
-    The relevant arguments received are:
+    The relevant expected arguments in *args* are:
         - *state*: used to enhance security during the authorization process, typically to provide *CSRF* protection
-        - *code*: the temporary authorization code, to be exchanged for the token
+        - *code*: the temporary authorization code provided by *iam_server*, to be exchanged for the token
 
     :param iam_server: the reference registered *IAM* server
     :param args: the arguments passed when requesting the service
@@ -215,11 +215,10 @@ def login_callback(iam_server: IamServer,
     result: tuple[str, str] | None = None
 
     with _iam_lock:
-        # retrieve the IAM server's registry and the data for all users therein
-        registry: dict[str, Any] = _get_iam_registry(iam_server=iam_server,
-                                                     errors=errors,
-                                                     logger=logger)
-        users: dict[str, dict[str, Any]] = (registry["cache"]["users"] or {}) if registry else {}
+        # retrieve the IAM server's data for all users
+        users: dict[str, dict[str, Any]] = _get_iam_users(iam_server=iam_server,
+                                                          errors=errors,
+                                                          logger=logger) or {}
         # retrieve the OAuth2 state
         oauth_state: str = args.get("state")
         user_data: dict[str, Any] | None = None
@@ -240,7 +239,7 @@ def login_callback(iam_server: IamServer,
                 body_data: dict[str, Any] = {
                     "grant_type": "authorization_code",
                     "code": code,
-                    "redirect_uri": registry["redirect-uri"]
+                    "redirect_uri": user_data.pop("redirect-uri")
                 }
                 now: int = int(datetime.now(tz=TZ_LOCAL).timestamp())
                 token_data: dict[str, Any] = __post_for_token(iam_server=iam_server,
@@ -256,7 +255,7 @@ def login_callback(iam_server: IamServer,
                                                   errors=errors,
                                                   logger=logger)
         else:
-            msg: str = "Unknown state received"
+            msg: str = f"State '{oauth_state}' not found in {iam_server}'s registry"
             if logger:
                 logger.error(msg=msg)
             if isinstance(errors, list):
@@ -273,7 +272,7 @@ def token_exchange(iam_server: IamServer,
     Request *iam_server* to issue a token in exchange for the token obtained from another *IAM* server.
 
     The expected parameters in *args* are:
-        - client-id: identification for the reference user (aliases: 'client_id', 'login')
+        - user-id: identification for the reference user (aliases: 'user_id', 'login')
         - token: the token to be exchanged
 
     The typical data set returned contains the following attributes:
@@ -399,14 +398,16 @@ def __post_for_token(iam_server: IamServer,
             # complete the data to send in body of request
             body_data["client_id"] = registry["client-id"]
             client_secret: str = registry["client-secret"]
-            if client_secret:
-                body_data["client_secret"] = client_secret
 
             # obtain the token
             url: str = registry["base-url"] + "/protocol/openid-connect/token"
+
+            # log the POST ('client_secret' data must not be shown in log)
             if logger:
-                logger.debug(msg=f"POST '{url}', data {json.dumps(obj=body_data,
-                                                                  ensure_ascii=False)}")
+                logger.debug(msg=f"POST {url}, {json.dumps(obj=body_data,
+                                                           ensure_ascii=False)}")
+            if client_secret:
+                body_data["client_secret"] = client_secret
             try:
                 # typical return on a token request:
                 # {
@@ -485,25 +486,24 @@ def __validate_and_store(iam_server: IamServer,
             user_data["access-expiration"] = now + token_data.get("expires_in")
             refresh_exp: int = user_data.get("refresh_expires_in")
             user_data["refresh-expiration"] = (now + refresh_exp) if refresh_exp else sys.maxsize
-            public_key: str = _get_public_key(iam_server=iam_server,
-                                              errors=errors,
-                                              logger=logger)
-            if public_key:
-                recipient_attr = registry["recipient_attr"]
-                login_id = user_data.pop("login-id", None)
-                claims: dict[str, dict[str, Any]] = token_validate(token=token,
-                                                                   issuer=registry["base-url"],
-                                                                   recipient_id=login_id,
-                                                                   recipient_attr=recipient_attr,
-                                                                   public_key=public_key,
-                                                                   errors=errors,
-                                                                   logger=logger)
-                if claims:
-                    users: dict[str, dict[str, Any]] = _get_iam_users(iam_server=iam_server,
-                                                                      errors=errors,
-                                                                      logger=logger)
-                    if users:
-                        user_id: str = login_id if login_id else claims["payload"][recipient_attr]
-                        users[user_id] = user_data
-                        result = (user_id, token)
+            # public_key: str = _get_public_key(iam_server=iam_server,
+            #                                   errors=errors,
+            #                                   logger=logger)
+            recipient_attr = registry["recipient-attr"]
+            login_id = user_data.pop("login-id", None)
+            claims: dict[str, dict[str, Any]] = token_validate(token=token,
+                                                               issuer=registry["base-url"],
+                                                               recipient_id=login_id,
+                                                               recipient_attr=recipient_attr,
+                                                               # public_key=public_key,
+                                                               errors=errors,
+                                                               logger=logger)
+            if claims:
+                users: dict[str, dict[str, Any]] = _get_iam_users(iam_server=iam_server,
+                                                                  errors=errors,
+                                                                  logger=logger)
+                if users:
+                    user_id: str = login_id if login_id else claims["payload"][recipient_attr]
+                    users[user_id] = user_data
+                    result = (user_id, token)
     return result
