@@ -1,4 +1,3 @@
-import sys
 from cachetools import Cache, FIFOCache
 from flask import Flask
 from logging import Logger
@@ -34,36 +33,36 @@ KEYCLOAK_URL_AUTH_BASE: Final[str] = env_get_str(key=f"{APP_PREFIX}_KEYCLOAK_URL
 
 
 def keycloak_setup(flask_app: Flask,
+                   base_url: str = KEYCLOAK_URL_AUTH_BASE,
+                   realm: str = KEYCLOAK_REALM,
                    client_id: str = KEYCLOAK_CLIENT_ID,
                    client_secret: str = KEYCLOAK_CLIENT_SECRET,
                    client_timeout: int = KEYCLOAK_CLIENT_TIMEOUT,
-                   public_key_lifetime: int = KEYCLOAK_PUBLIC_KEY_LIFETIME,
-                   recipient_attribute: str = KEYCLOAK_RECIPIENT_ATTR,
-                   realm: str = KEYCLOAK_REALM,
-                   callback_endpoint: str = KEYCLOAK_ENDPOINT_CALLBACK,
-                   exchange_endpoint: str = KEYCLOAK_ENDPOINT_EXCHANGE,
-                   login_endpoint: str = KEYCLOAK_ENDPOINT_LOGIN,
-                   logout_endpoint: str = KEYCLOAK_ENDPOINT_LOGOUT,
-                   token_endpoint: str = KEYCLOAK_ENDPOINT_TOKEN,
-                   base_url: str = KEYCLOAK_URL_AUTH_BASE) -> None:
+                   public_key_lifetime: int | None = KEYCLOAK_PUBLIC_KEY_LIFETIME,
+                   recipient_attribute: str | None = KEYCLOAK_RECIPIENT_ATTR,
+                   callback_endpoint: str | None = KEYCLOAK_ENDPOINT_CALLBACK,
+                   login_endpoint: str | None = KEYCLOAK_ENDPOINT_LOGIN,
+                   logout_endpoint: str | None = KEYCLOAK_ENDPOINT_LOGOUT,
+                   token_endpoint: str | None = KEYCLOAK_ENDPOINT_TOKEN,
+                   exchange_endpoint: str | None = KEYCLOAK_ENDPOINT_EXCHANGE) -> None:
     """
     Configure the Keycloak IAM.
 
     This should be invoked only once, before the first access to a Keycloak service.
 
     :param flask_app: the Flask application
+    :param base_url: base URL to request Keycloak services
+    :param realm: the Keycloak realm
     :param client_id: the client's identification with JusBR
     :param client_secret: the client's password with JusBR
     :param client_timeout: timeout for login authentication (in seconds,defaults to no timeout)
     :param public_key_lifetime: how long to use Keycloak's public key, before refreshing it (in seconds)
     :param recipient_attribute: attribute in the token's payload holding the token's subject
-    :param realm: the Keycloak realm
     :param callback_endpoint: endpoint for the callback from the front end
-    :param exchange_endpoint: endpoint fro requesting token exchange
-    :param token_endpoint: endpoint for retrieving Keycloak's authentication token
     :param login_endpoint: endpoint for redirecting user to Keycloak's login page
     :param logout_endpoint: endpoint for terminating user access to Keycloak
-    :param base_url: base URL to request Keycloak services
+    :param token_endpoint: endpoint for retrieving Keycloak's authentication token
+    :param exchange_endpoint: endpoint for requesting token exchange
     """
     from .iam_services import (
         service_login, service_logout, service_callback, service_exchange, service_token
@@ -74,18 +73,23 @@ def keycloak_setup(flask_app: Flask,
     cache["users"] = {}
     with _iam_lock:
         _IAM_SERVERS[IamServer.IAM_KEYCLOAK] = {
+            "base-url": f"{base_url}/realms/{realm}",
             "client-id": client_id,
             "client-secret": client_secret,
             "client-timeout": client_timeout,
-            "recipient-attr": recipient_attribute,
-            "base-url": f"{base_url}/realms/{realm}",
-            "pk-expiration": sys.maxsize,
+            "public-key": None,
             "pk-lifetime": public_key_lifetime,
-            "cache": cache,
-            "redirect-uri": None
+            "pk-expiration": 0,
+            "recipient-attr": recipient_attribute,
+            "cache": cache
         }
 
     # establish the endpoints
+    if callback_endpoint:
+        flask_app.add_url_rule(rule=callback_endpoint,
+                               endpoint="keycloak-callback",
+                               view_func=service_callback,
+                               methods=["GET"])
     if login_endpoint:
         flask_app.add_url_rule(rule=login_endpoint,
                                endpoint="keycloak-login",
@@ -96,11 +100,6 @@ def keycloak_setup(flask_app: Flask,
                                endpoint="keycloak-logout",
                                view_func=service_logout,
                                methods=["GET"])
-    if callback_endpoint:
-        flask_app.add_url_rule(rule=callback_endpoint,
-                               endpoint="keycloak-callback",
-                               view_func=service_callback,
-                               methods=["GET"])
     if token_endpoint:
         flask_app.add_url_rule(rule=token_endpoint,
                                endpoint="keycloak-token",
